@@ -1,3 +1,4 @@
+import requests
 from typing import Union
 from ...base import Base2Vec
 from ...import_utils import is_all_dependency_installed
@@ -8,7 +9,6 @@ if is_all_dependency_installed('encoders-image'):
     import numpy as np
     import matplotlib.pyplot as plt
     from urllib.request import urlopen, Request
-    from urllib.parse import quote
     from skimage import transform
 
 class BaseImage2Vec(Base2Vec):
@@ -19,15 +19,19 @@ class BaseImage2Vec(Base2Vec):
                 image: An image link/bytes/io Bytesio data format.
                 as_gray: read in the image as black and white
         """
-        if type(image) == str:
+        if type(image) is str:
             if 'http' in image:
-                b = io.BytesIO(urlopen(Request(
-                    quote(image, safe=':/?*=\''), headers={'User-Agent': "Mozilla/5.0"})).read())
+                try:
+                    b = io.BytesIO(urlopen(Request(
+                        image, headers={'User-Agent': "Mozilla/5.0"})).read())
+                except:
+                    import tensorflow as tf
+                    return tf.image.decode_jpeg(requests.get(image).content, channels=3, name="jpeg_reader").numpy()
             else:
                 b = image
-        elif type(image) == bytes:
+        elif type(image) is bytes:
             b = io.BytesIO(image)
-        elif type(image) == io.BytesIO:
+        elif type(image) is io.BytesIO:
             b = image
         else:
             raise ValueError("Cannot process data type. Ensure it is is string/bytes or BytesIO.")
